'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _async = require('async');

var _async2 = _interopRequireDefault(_async);

var util = require('./util/urls');

exports['default'] = function (settings, file, next) {
  var config = _fs2['default'].readFileSync(file);
  var json = null;
  var id = null;

  try {
    json = JSON.parse(config);
  } catch (e) {
    console.error(e);
    next(false);
    return;
  }

  if (json.app && json.app.id) {
    id = json.app.id;
  } else {
    console.error('id is not specified');
    next(false);
    return;
  }

  _async2['default'].series([function (cb) {
    settings.set(id, 'app', json.app, cb);
  }, function (cb) {
    settings.set(id, 'oauth', json.oauth, cb);
  }, function (cb) {
    settings.set(id, 'merchant', json.merchant, cb);
  }, function (cb) {
    settings.set(id, 'message', json.message, cb);
  }, function (cb) {
    settings.set(id, 'certificate', {
      pfx: _fs2['default'].readFileSync(_path2['default'].resolve(json.certificate.file)),
      pfxKey: json.certificate.key
    }, cb);
  }, function (cb) {
    var host = json.server.host || 'localhost';
    settings.set(id, 'host', host, cb);
  }, function (cb) {
    var host = json.server.host || 'localhost';
    var prefix = json.server.prefix || 'weixin';
    var urls = util.generate(util.base(host, id), prefix);
    settings.set(id, 'urls', urls, cb);
  }], function () {
    next(id);
  });
};

module.exports = exports['default'];