'use strict';

var express = require('express');
var bodyParser = require('body-parser');
var expressSession = require('express-session');
var cookieParser = require('cookie-parser');
var weixinRouter = require('node-weixin-router');

var routers = require('../router/express');
var session = require('../mySession');
var async = require('async');

module.exports = {
  /**
   * default express server
   * @returns {*}
   */
  prepare: function prepare() {

    var http = express();

    http.use(bodyParser.urlencoded({ extended: false }));
    http.use(bodyParser.json());
    http.use(bodyParser.raw({ type: 'text/xml' }));
    http.use(cookieParser());
    http.set('trust proxy', 1); // trust first proxy
    http.use(expressSession({ secret: 'osososss', cookie: { maxAge: 60000 }, resave: true, saveUninitialized: true }));
    return http;
  },
  initCallbacks: function initCallbacks() {

    var order = require('../listeners/order');
    var oauth = require('../listeners/oauth');

    weixinRouter.onCreate(order.onCreate);
    weixinRouter.onNotify(order.onNotify);
    weixinRouter.onOauth(oauth.onOAuth);
  },

  /**
   *
   * @param port
   * @param host
   * @param prefix
   * @param http
   * @returns {*}
   */
  start: function start(port, host, prefix, http, next) {
    var self = this;
    async.series([function (cb) {
      session.set(null, 'host', host, cb);
    }, function (cb) {
      session.set(null, 'port', port, cb);
    }, function (cb) {
      session.set(null, 'prefix', prefix, cb);
    }], function () {
      http = http || self.prepare();
      routers.forEach(function (router) {
        http.use(router.path, router.router);
      });
      next();
    });
  }
};